==> gnumeric-0.74.tar.bz2: gnumeric-0.74/src/gnumeric-pane.h <==
#ifndef GNUMERIC_PANE_H
#define GNUMERIC_PANE_H

#include "gui-gnumeric.h"

struct _GnumericPane {
	GList		*anted_cursors;
	int		 index;
	GnumericCanvas	*gcanvas;
	struct {
		GnomeCanvas *canvas;
		ItemBar     *item;
	} col, row;

	/* Lines for resizing cols and rows */
	struct {
		GtkObject         *guide;
		GtkObject         *start;
		GnomeCanvasPoints *points;
	} colrow_resize;

	ItemGrid      *grid;
	ItemEdit      *editor;

	struct {
		ItemCursor *std, *rangesel, *special;
	} cursor;
};

void gnm_pane_init	(GnumericPane *pane, SheetControlGUI *scg,
			 gboolean headers, int index);
void gnm_pane_release	(GnumericPane *pane);
void gnm_pane_bound_set	(GnumericPane *pane,
			 int start_col, int start_row,
			 int end_col, int end_row);

void gnm_pane_edit_start		(GnumericPane *gsheet);
void gnm_pane_edit_stop			(GnumericPane *gsheet);

void gnm_pane_colrow_resize_stop	(GnumericPane *pane);
void gnm_pane_colrow_resize_start	(GnumericPane *pane,
					 gboolean is_cols, int resize_pos);
void gnm_pane_colrow_resize_move	(GnumericPane *pane,
					 gboolean is_cols, int resize_pos);

void gnm_pane_reposition_cursors		(GnumericPane *pane);
gboolean gnm_pane_cursor_bound_set	 	(GnumericPane *pane, Range const *r);
gboolean gnm_pane_rangesel_bound_set		(GnumericPane *pane, Range const *r);
void gnm_pane_rangesel_start			(GnumericPane *pane, int col, int row);
void gnm_pane_rangesel_stop			(GnumericPane *pane);
gboolean gnm_pane_special_cursor_bound_set	(GnumericPane *pane, Range const *r);
void gnm_pane_special_cursor_start 		(GnumericPane *pane, int style, int button);
void gnm_pane_special_cursor_stop		(GnumericPane *pane);

#endif /* GNUMERIC_PANE_H */

==> gnumeric-1.1.1.tar.bz2: gnumeric-1.1.1/src/gnumeric-pane.h <==
#ifndef GNUMERIC_PANE_H
#define GNUMERIC_PANE_H

#include "gui-gnumeric.h"
#include <libgnomecanvas/gnome-canvas-util.h>

struct _GnumericPane {
	GList		*anted_cursors;
	int		 index;
	GnumericCanvas	*gcanvas;
	struct {
		GnomeCanvas *canvas;
		ItemBar     *item;
	} col, row;

	/* Lines for resizing cols and rows */
	struct {
		GtkObject         *guide;
		GtkObject         *start;
		GnomeCanvasPoints *points;
	} colrow_resize;

	ItemGrid      *grid;
	ItemEdit      *editor;

	struct {
		ItemCursor *std, *rangesel, *special;
	} cursor;
};

void gnm_pane_init	(GnumericPane *pane, SheetControlGUI *scg,
			 gboolean headers, int index);
void gnm_pane_release	(GnumericPane *pane);
void gnm_pane_bound_set	(GnumericPane *pane,
			 int start_col, int start_row,
			 int end_col, int end_row);

void gnm_pane_edit_start		(GnumericPane *gsheet);
void gnm_pane_edit_stop			(GnumericPane *gsheet);

void gnm_pane_colrow_resize_stop	(GnumericPane *pane);
void gnm_pane_colrow_resize_start	(GnumericPane *pane,
					 gboolean is_cols, int resize_pos);
void gnm_pane_colrow_resize_move	(GnumericPane *pane,
					 gboolean is_cols, int resize_pos);

void gnm_pane_reposition_cursors		(GnumericPane *pane);
gboolean gnm_pane_cursor_bound_set	 	(GnumericPane *pane, Range const *r);
gboolean gnm_pane_rangesel_bound_set		(GnumericPane *pane, Range const *r);
void gnm_pane_rangesel_start			(GnumericPane *pane, Range const *r);
void gnm_pane_rangesel_stop			(GnumericPane *pane);
gboolean gnm_pane_special_cursor_bound_set	(GnumericPane *pane, Range const *r);
void gnm_pane_special_cursor_start 		(GnumericPane *pane, int style, int button);
void gnm_pane_special_cursor_stop		(GnumericPane *pane);

#endif /* GNUMERIC_PANE_H */
